[−][src]Enum unicode_types::cuneiform::Cuneiform
An enum to represent all characters in the Cuneiform block.
Variants
SignA\u{12000}: '𒀀'
SignATimesA\u{12001}: '𒀁'
SignATimesBad\u{12002}: '𒀂'
SignATimesGan2Tenu\u{12003}: '𒀃'
SignATimesHa\u{12004}: '𒀄'
SignATimesIgi\u{12005}: '𒀅'
SignATimesLagarGunu\u{12006}: '𒀆'
SignATimesMush\u{12007}: '𒀇'
SignATimesSag\u{12008}: '𒀈'
SignA2\u{12009}: '𒀉'
SignAb\u{1200a}: '𒀊'
SignAbTimesAsh2\u{1200b}: '𒀋'
SignAbTimesDun3Gunu\u{1200c}: '𒀌'
SignAbTimesGal\u{1200d}: '𒀍'
SignAbTimesGan2Tenu\u{1200e}: '𒀎'
SignAbTimesHa\u{1200f}: '𒀏'
SignAbTimesIgiGunu\u{12010}: '𒀐'
SignAbTimesImin\u{12011}: '𒀑'
SignAbTimesLagab\u{12012}: '𒀒'
SignAbTimesShesh\u{12013}: '𒀓'
SignAbTimesUPlusUPlusU\u{12014}: '𒀔'
SignAbGunu\u{12015}: '𒀕'
SignAb2\u{12016}: '𒀖'
SignAb2TimesBalag\u{12017}: '𒀗'
SignAb2TimesGan2Tenu\u{12018}: '𒀘'
SignAb2TimesMePlusEn\u{12019}: '𒀙'
SignAb2TimesSha3\u{1201a}: '𒀚'
SignAb2TimesTak4\u{1201b}: '𒀛'
SignAd\u{1201c}: '𒀜'
SignAk\u{1201d}: '𒀝'
SignAkTimesErin2\u{1201e}: '𒀞'
SignAkTimesShitaPlusGish\u{1201f}: '𒀟'
SignAl\u{12020}: '𒀠'
SignAlTimesAl\u{12021}: '𒀡'
SignAlTimesDim2\u{12022}: '𒀢'
SignAlTimesGish\u{12023}: '𒀣'
SignAlTimesHa\u{12024}: '𒀤'
SignAlTimesKad3\u{12025}: '𒀥'
SignAlTimesKi\u{12026}: '𒀦'
SignAlTimesShe\u{12027}: '𒀧'
SignAlTimesUsh\u{12028}: '𒀨'
SignAlan\u{12029}: '𒀩'
SignAleph\u{1202a}: '𒀪'
SignAmar\u{1202b}: '𒀫'
SignAmarTimesShe\u{1202c}: '𒀬'
SignAn\u{1202d}: '𒀭'
SignAnOverAn\u{1202e}: '𒀮'
SignAnThreeTimes\u{1202f}: '𒀯'
SignAnPlusNagaOpposingAnPlusNaga\u{12030}: '𒀰'
SignAnPlusNagaSquared\u{12031}: '𒀱'
SignAnshe\u{12032}: '𒀲'
SignApin\u{12033}: '𒀳'
SignArad\u{12034}: '𒀴'
SignAradTimesKur\u{12035}: '𒀵'
SignArkab\u{12036}: '𒀶'
SignAsal2\u{12037}: '𒀷'
SignAsh\u{12038}: '𒀸'
SignAshZidaTenu\u{12039}: '𒀹'
SignAshKabaTenu\u{1203a}: '𒀺'
SignAshOverAshTug2OverTug2Tug2OverTug2Pap\u{1203b}: '𒀻'
SignAshOverAshOverAsh\u{1203c}: '𒀼'
SignAshOverAshOverAshCrossingAshOverAshOverAsh\u{1203d}: '𒀽'
SignAsh2\u{1203e}: '𒀾'
SignAshgab\u{1203f}: '𒀿'
SignBa\u{12040}: '𒁀'
SignBad\u{12041}: '𒁁'
SignBag3\u{12042}: '𒁂'
SignBahar2\u{12043}: '𒁃'
SignBal\u{12044}: '𒁄'
SignBalOverBal\u{12045}: '𒁅'
SignBalag\u{12046}: '𒁆'
SignBar\u{12047}: '𒁇'
SignBara2\u{12048}: '𒁈'
SignBi\u{12049}: '𒁉'
SignBiTimesA\u{1204a}: '𒁊'
SignBiTimesGar\u{1204b}: '𒁋'
SignBiTimesIgiGunu\u{1204c}: '𒁌'
SignBu\u{1204d}: '𒁍'
SignBuOverBuAb\u{1204e}: '𒁎'
SignBuOverBuUn\u{1204f}: '𒁏'
SignBuCrossingBu\u{12050}: '𒁐'
SignBulug\u{12051}: '𒁑'
SignBulugOverBulug\u{12052}: '𒁒'
SignBur\u{12053}: '𒁓'
SignBur2\u{12054}: '𒁔'
SignDa\u{12055}: '𒁕'
SignDag\u{12056}: '𒁖'
SignDagKisim5TimesAPlusMash\u{12057}: '𒁗'
SignDagKisim5TimesAmar\u{12058}: '𒁘'
SignDagKisim5TimesBalag\u{12059}: '𒁙'
SignDagKisim5TimesBi\u{1205a}: '𒁚'
SignDagKisim5TimesGa\u{1205b}: '𒁛'
SignDagKisim5TimesGaPlusMash\u{1205c}: '𒁜'
SignDagKisim5TimesGi\u{1205d}: '𒁝'
SignDagKisim5TimesGir2\u{1205e}: '𒁞'
SignDagKisim5TimesGud\u{1205f}: '𒁟'
SignDagKisim5TimesHa\u{12060}: '𒁠'
SignDagKisim5TimesIr\u{12061}: '𒁡'
SignDagKisim5TimesIrPlusLu\u{12062}: '𒁢'
SignDagKisim5TimesKak\u{12063}: '𒁣'
SignDagKisim5TimesLa\u{12064}: '𒁤'
SignDagKisim5TimesLu\u{12065}: '𒁥'
SignDagKisim5TimesLuPlusMash2\u{12066}: '𒁦'
SignDagKisim5TimesLum\u{12067}: '𒁧'
SignDagKisim5TimesNe\u{12068}: '𒁨'
SignDagKisim5TimesPapPlusPap\u{12069}: '𒁩'
SignDagKisim5TimesSi\u{1206a}: '𒁪'
SignDagKisim5TimesTak4\u{1206b}: '𒁫'
SignDagKisim5TimesU2PlusGir2\u{1206c}: '𒁬'
SignDagKisim5TimesUsh\u{1206d}: '𒁭'
SignDam\u{1206e}: '𒁮'
SignDar\u{1206f}: '𒁯'
SignDara3\u{12070}: '𒁰'
SignDara4\u{12071}: '𒁱'
SignDi\u{12072}: '𒁲'
SignDib\u{12073}: '𒁳'
SignDim\u{12074}: '𒁴'
SignDimTimesShe\u{12075}: '𒁵'
SignDim2\u{12076}: '𒁶'
SignDin\u{12077}: '𒁷'
SignDinKaskalUGunuDish\u{12078}: '𒁸'
SignDish\u{12079}: '𒁹'
SignDu\u{1207a}: '𒁺'
SignDuOverDu\u{1207b}: '𒁻'
SignDuGunu\u{1207c}: '𒁼'
SignDuSheshig\u{1207d}: '𒁽'
SignDub\u{1207e}: '𒁾'
SignDubTimesEsh2\u{1207f}: '𒁿'
SignDub2\u{12080}: '𒂀'
SignDug\u{12081}: '𒂁'
SignDugud\u{12082}: '𒂂'
SignDuh\u{12083}: '𒂃'
SignDun\u{12084}: '𒂄'
SignDun3\u{12085}: '𒂅'
SignDun3Gunu\u{12086}: '𒂆'
SignDun3GunuGunu\u{12087}: '𒂇'
SignDun4\u{12088}: '𒂈'
SignDur2\u{12089}: '𒂉'
SignE\u{1208a}: '𒂊'
SignETimesPap\u{1208b}: '𒂋'
SignEOverENunOverNun\u{1208c}: '𒂌'
SignE2\u{1208d}: '𒂍'
SignE2TimesAPlusHaPlusDa\u{1208e}: '𒂎'
SignE2TimesGar\u{1208f}: '𒂏'
SignE2TimesMi\u{12090}: '𒂐'
SignE2TimesSal\u{12091}: '𒂑'
SignE2TimesShe\u{12092}: '𒂒'
SignE2TimesU\u{12093}: '𒂓'
SignEdin\u{12094}: '𒂔'
SignEgir\u{12095}: '𒂕'
SignEl\u{12096}: '𒂖'
SignEn\u{12097}: '𒂗'
SignEnTimesGan2\u{12098}: '𒂘'
SignEnTimesGan2Tenu\u{12099}: '𒂙'
SignEnTimesMe\u{1209a}: '𒂚'
SignEnCrossingEn\u{1209b}: '𒂛'
SignEnOpposingEn\u{1209c}: '𒂜'
SignEnSquared\u{1209d}: '𒂝'
SignEren\u{1209e}: '𒂞'
SignErin2\u{1209f}: '𒂟'
SignEsh2\u{120a0}: '𒂠'
SignEzen\u{120a1}: '𒂡'
SignEzenTimesA\u{120a2}: '𒂢'
SignEzenTimesAPlusLal\u{120a3}: '𒂣'
SignEzenTimesAPlusLalTimesLal\u{120a4}: '𒂤'
SignEzenTimesAn\u{120a5}: '𒂥'
SignEzenTimesBad\u{120a6}: '𒂦'
SignEzenTimesDun3Gunu\u{120a7}: '𒂧'
SignEzenTimesDun3GunuGunu\u{120a8}: '𒂨'
SignEzenTimesHa\u{120a9}: '𒂩'
SignEzenTimesHaGunu\u{120aa}: '𒂪'
SignEzenTimesIgiGunu\u{120ab}: '𒂫'
SignEzenTimesKaskal\u{120ac}: '𒂬'
SignEzenTimesKaskalSquared\u{120ad}: '𒂭'
SignEzenTimesKu3\u{120ae}: '𒂮'
SignEzenTimesLa\u{120af}: '𒂯'
SignEzenTimesLalTimesLal\u{120b0}: '𒂰'
SignEzenTimesLi\u{120b1}: '𒂱'
SignEzenTimesLu\u{120b2}: '𒂲'
SignEzenTimesU2\u{120b3}: '𒂳'
SignEzenTimesUd\u{120b4}: '𒂴'
SignGa\u{120b5}: '𒂵'
SignGaGunu\u{120b6}: '𒂶'
SignGa2\u{120b7}: '𒂷'
SignGa2TimesAPlusDaPlusHa\u{120b8}: '𒂸'
SignGa2TimesAPlusHa\u{120b9}: '𒂹'
SignGa2TimesAPlusIgi\u{120ba}: '𒂺'
SignGa2TimesAb2TenuPlusTab\u{120bb}: '𒂻'
SignGa2TimesAn\u{120bc}: '𒂼'
SignGa2TimesAsh\u{120bd}: '𒂽'
SignGa2TimesAsh2PlusGal\u{120be}: '𒂾'
SignGa2TimesBad\u{120bf}: '𒂿'
SignGa2TimesBarPlusRa\u{120c0}: '𒃀'
SignGa2TimesBur\u{120c1}: '𒃁'
SignGa2TimesBurPlusRa\u{120c2}: '𒃂'
SignGa2TimesDa\u{120c3}: '𒃃'
SignGa2TimesDi\u{120c4}: '𒃄'
SignGa2TimesDimTimesShe\u{120c5}: '𒃅'
SignGa2TimesDub\u{120c6}: '𒃆'
SignGa2TimesEl\u{120c7}: '𒃇'
SignGa2TimesElPlusLa\u{120c8}: '𒃈'
SignGa2TimesEn\u{120c9}: '𒃉'
SignGa2TimesEnTimesGan2Tenu\u{120ca}: '𒃊'
SignGa2TimesGan2Tenu\u{120cb}: '𒃋'
SignGa2TimesGar\u{120cc}: '𒃌'
SignGa2TimesGi\u{120cd}: '𒃍'
SignGa2TimesGi4\u{120ce}: '𒃎'
SignGa2TimesGi4PlusA\u{120cf}: '𒃏'
SignGa2TimesGir2PlusSu\u{120d0}: '𒃐'
SignGa2TimesHaPlusLuPlusEsh2\u{120d1}: '𒃑'
SignGa2TimesHal\u{120d2}: '𒃒'
SignGa2TimesHalPlusLa\u{120d3}: '𒃓'
SignGa2TimesHiPlusLi\u{120d4}: '𒃔'
SignGa2TimesHub2\u{120d5}: '𒃕'
SignGa2TimesIgiGunu\u{120d6}: '𒃖'
SignGa2TimesIshPlusHuPlusAsh\u{120d7}: '𒃗'
SignGa2TimesKak\u{120d8}: '𒃘'
SignGa2TimesKaskal\u{120d9}: '𒃙'
SignGa2TimesKid\u{120da}: '𒃚'
SignGa2TimesKidPlusLal\u{120db}: '𒃛'
SignGa2TimesKu3PlusAn\u{120dc}: '𒃜'
SignGa2TimesLa\u{120dd}: '𒃝'
SignGa2TimesMePlusEn\u{120de}: '𒃞'
SignGa2TimesMi\u{120df}: '𒃟'
SignGa2TimesNun\u{120e0}: '𒃠'
SignGa2TimesNunOverNun\u{120e1}: '𒃡'
SignGa2TimesPa\u{120e2}: '𒃢'
SignGa2TimesSal\u{120e3}: '𒃣'
SignGa2TimesSar\u{120e4}: '𒃤'
SignGa2TimesShe\u{120e5}: '𒃥'
SignGa2TimesShePlusTur\u{120e6}: '𒃦'
SignGa2TimesShid\u{120e7}: '𒃧'
SignGa2TimesSum\u{120e8}: '𒃨'
SignGa2TimesTak4\u{120e9}: '𒃩'
SignGa2TimesU\u{120ea}: '𒃪'
SignGa2TimesUd\u{120eb}: '𒃫'
SignGa2TimesUdPlusDu\u{120ec}: '𒃬'
SignGa2OverGa2\u{120ed}: '𒃭'
SignGaba\u{120ee}: '𒃮'
SignGabaCrossingGaba\u{120ef}: '𒃯'
SignGad\u{120f0}: '𒃰'
SignGadOverGadGarOverGar\u{120f1}: '𒃱'
SignGal\u{120f2}: '𒃲'
SignGalGadOverGadGarOverGar\u{120f3}: '𒃳'
SignGalam\u{120f4}: '𒃴'
SignGam\u{120f5}: '𒃵'
SignGan\u{120f6}: '𒃶'
SignGan2\u{120f7}: '𒃷'
SignGan2Tenu\u{120f8}: '𒃸'
SignGan2OverGan2\u{120f9}: '𒃹'
SignGan2CrossingGan2\u{120fa}: '𒃺'
SignGar\u{120fb}: '𒃻'
SignGar3\u{120fc}: '𒃼'
SignGashan\u{120fd}: '𒃽'
SignGeshtin\u{120fe}: '𒃾'
SignGeshtinTimesKur\u{120ff}: '𒃿'
SignGi\u{12100}: '𒄀'
SignGiTimesE\u{12101}: '𒄁'
SignGiTimesU\u{12102}: '𒄂'
SignGiCrossingGi\u{12103}: '𒄃'
SignGi4\u{12104}: '𒄄'
SignGi4OverGi4\u{12105}: '𒄅'
SignGi4CrossingGi4\u{12106}: '𒄆'
SignGidim\u{12107}: '𒄇'
SignGir2\u{12108}: '𒄈'
SignGir2Gunu\u{12109}: '𒄉'
SignGir3\u{1210a}: '𒄊'
SignGir3TimesAPlusIgi\u{1210b}: '𒄋'
SignGir3TimesGan2Tenu\u{1210c}: '𒄌'
SignGir3TimesIgi\u{1210d}: '𒄍'
SignGir3TimesLuPlusIgi\u{1210e}: '𒄎'
SignGir3TimesPa\u{1210f}: '𒄏'
SignGisal\u{12110}: '𒄐'
SignGish\u{12111}: '𒄑'
SignGishCrossingGish\u{12112}: '𒄒'
SignGishTimesBad\u{12113}: '𒄓'
SignGishTimesTak4\u{12114}: '𒄔'
SignGishTenu\u{12115}: '𒄕'
SignGu\u{12116}: '𒄖'
SignGuCrossingGu\u{12117}: '𒄗'
SignGu2\u{12118}: '𒄘'
SignGu2TimesKak\u{12119}: '𒄙'
SignGu2TimesKakTimesIgiGunu\u{1211a}: '𒄚'
SignGu2TimesNun\u{1211b}: '𒄛'
SignGu2TimesSalPlusTug2\u{1211c}: '𒄜'
SignGu2Gunu\u{1211d}: '𒄝'
SignGud\u{1211e}: '𒄞'
SignGudTimesAPlusKur\u{1211f}: '𒄟'
SignGudTimesKur\u{12120}: '𒄠'
SignGudOverGudLugal\u{12121}: '𒄡'
SignGul\u{12122}: '𒄢'
SignGum\u{12123}: '𒄣'
SignGumTimesShe\u{12124}: '𒄤'
SignGur\u{12125}: '𒄥'
SignGur7\u{12126}: '𒄦'
SignGurun\u{12127}: '𒄧'
SignGurush\u{12128}: '𒄨'
SignHa\u{12129}: '𒄩'
SignHaTenu\u{1212a}: '𒄪'
SignHaGunu\u{1212b}: '𒄫'
SignHal\u{1212c}: '𒄬'
SignHi\u{1212d}: '𒄭'
SignHiTimesAsh\u{1212e}: '𒄮'
SignHiTimesAsh2\u{1212f}: '𒄯'
SignHiTimesBad\u{12130}: '𒄰'
SignHiTimesDish\u{12131}: '𒄱'
SignHiTimesGad\u{12132}: '𒄲'
SignHiTimesKin\u{12133}: '𒄳'
SignHiTimesNun\u{12134}: '𒄴'
SignHiTimesShe\u{12135}: '𒄵'
SignHiTimesU\u{12136}: '𒄶'
SignHu\u{12137}: '𒄷'
SignHub2\u{12138}: '𒄸'
SignHub2TimesAn\u{12139}: '𒄹'
SignHub2TimesHal\u{1213a}: '𒄺'
SignHub2TimesKaskal\u{1213b}: '𒄻'
SignHub2TimesLish\u{1213c}: '𒄼'
SignHub2TimesUd\u{1213d}: '𒄽'
SignHul2\u{1213e}: '𒄾'
SignI\u{1213f}: '𒄿'
SignIA\u{12140}: '𒅀'
SignIb\u{12141}: '𒅁'
SignIdim\u{12142}: '𒅂'
SignIdimOverIdimBur\u{12143}: '𒅃'
SignIdimOverIdimSquared\u{12144}: '𒅄'
SignIg\u{12145}: '𒅅'
SignIgi\u{12146}: '𒅆'
SignIgiDib\u{12147}: '𒅇'
SignIgiRi\u{12148}: '𒅈'
SignIgiOverIgiShirOverShirUdOverUd\u{12149}: '𒅉'
SignIgiGunu\u{1214a}: '𒅊'
SignIl\u{1214b}: '𒅋'
SignIlTimesGan2Tenu\u{1214c}: '𒅌'
SignIl2\u{1214d}: '𒅍'
SignIm\u{1214e}: '𒅎'
SignImTimesTak4\u{1214f}: '𒅏'
SignImCrossingIm\u{12150}: '𒅐'
SignImOpposingIm\u{12151}: '𒅑'
SignImSquared\u{12152}: '𒅒'
SignImin\u{12153}: '𒅓'
SignIn\u{12154}: '𒅔'
SignIr\u{12155}: '𒅕'
SignIsh\u{12156}: '𒅖'
SignKa\u{12157}: '𒅗'
SignKaTimesA\u{12158}: '𒅘'
SignKaTimesAd\u{12159}: '𒅙'
SignKaTimesAdPlusKu3\u{1215a}: '𒅚'
SignKaTimesAsh2\u{1215b}: '𒅛'
SignKaTimesBad\u{1215c}: '𒅜'
SignKaTimesBalag\u{1215d}: '𒅝'
SignKaTimesBar\u{1215e}: '𒅞'
SignKaTimesBi\u{1215f}: '𒅟'
SignKaTimesErin2\u{12160}: '𒅠'
SignKaTimesEsh2\u{12161}: '𒅡'
SignKaTimesGa\u{12162}: '𒅢'
SignKaTimesGal\u{12163}: '𒅣'
SignKaTimesGan2Tenu\u{12164}: '𒅤'
SignKaTimesGar\u{12165}: '𒅥'
SignKaTimesGarPlusSha3PlusA\u{12166}: '𒅦'
SignKaTimesGi\u{12167}: '𒅧'
SignKaTimesGir2\u{12168}: '𒅨'
SignKaTimesGishPlusSar\u{12169}: '𒅩'
SignKaTimesGishCrossingGish\u{1216a}: '𒅪'
SignKaTimesGu\u{1216b}: '𒅫'
SignKaTimesGur7\u{1216c}: '𒅬'
SignKaTimesIgi\u{1216d}: '𒅭'
SignKaTimesIm\u{1216e}: '𒅮'
SignKaTimesKak\u{1216f}: '𒅯'
SignKaTimesKi\u{12170}: '𒅰'
SignKaTimesKid\u{12171}: '𒅱'
SignKaTimesLi\u{12172}: '𒅲'
SignKaTimesLu\u{12173}: '𒅳'
SignKaTimesMe\u{12174}: '𒅴'
SignKaTimesMePlusDu\u{12175}: '𒅵'
SignKaTimesMePlusGi\u{12176}: '𒅶'
SignKaTimesMePlusTe\u{12177}: '𒅷'
SignKaTimesMi\u{12178}: '𒅸'
SignKaTimesMiPlusNunuz\u{12179}: '𒅹'
SignKaTimesNe\u{1217a}: '𒅺'
SignKaTimesNun\u{1217b}: '𒅻'
SignKaTimesPi\u{1217c}: '𒅼'
SignKaTimesRu\u{1217d}: '𒅽'
SignKaTimesSa\u{1217e}: '𒅾'
SignKaTimesSar\u{1217f}: '𒅿'
SignKaTimesSha\u{12180}: '𒆀'
SignKaTimesShe\u{12181}: '𒆁'
SignKaTimesShid\u{12182}: '𒆂'
SignKaTimesShu\u{12183}: '𒆃'
SignKaTimesSig\u{12184}: '𒆄'
SignKaTimesSuhur\u{12185}: '𒆅'
SignKaTimesTar\u{12186}: '𒆆'
SignKaTimesU\u{12187}: '𒆇'
SignKaTimesU2\u{12188}: '𒆈'
SignKaTimesUd\u{12189}: '𒆉'
SignKaTimesUmumTimesPa\u{1218a}: '𒆊'
SignKaTimesUsh\u{1218b}: '𒆋'
SignKaTimesZi\u{1218c}: '𒆌'
SignKa2\u{1218d}: '𒆍'
SignKa2CrossingKa2\u{1218e}: '𒆎'
SignKab\u{1218f}: '𒆏'
SignKad2\u{12190}: '𒆐'
SignKad3\u{12191}: '𒆑'
SignKad4\u{12192}: '𒆒'
SignKad5\u{12193}: '𒆓'
SignKad5OverKad5\u{12194}: '𒆔'
SignKak\u{12195}: '𒆕'
SignKakTimesIgiGunu\u{12196}: '𒆖'
SignKal\u{12197}: '𒆗'
SignKalTimesBad\u{12198}: '𒆘'
SignKalCrossingKal\u{12199}: '𒆙'
SignKam2\u{1219a}: '𒆚'
SignKam4\u{1219b}: '𒆛'
SignKaskal\u{1219c}: '𒆜'
SignKaskalLagabTimesUOverLagabTimesU\u{1219d}: '𒆝'
SignKaskalOverKaskalLagabTimesUOverLagabTimesU\u{1219e}: '𒆞'
SignKesh2\u{1219f}: '𒆟'
SignKi\u{121a0}: '𒆠'
SignKiTimesBad\u{121a1}: '𒆡'
SignKiTimesU\u{121a2}: '𒆢'
SignKiTimesUd\u{121a3}: '𒆣'
SignKid\u{121a4}: '𒆤'
SignKin\u{121a5}: '𒆥'
SignKisal\u{121a6}: '𒆦'
SignKish\u{121a7}: '𒆧'
SignKisim5\u{121a8}: '𒆨'
SignKisim5OverKisim5\u{121a9}: '𒆩'
SignKu\u{121aa}: '𒆪'
SignKuOverHiTimesAsh2KuOverHiTimesAsh2\u{121ab}: '𒆫'
SignKu3\u{121ac}: '𒆬'
SignKu4\u{121ad}: '𒆭'
SignKu4VariantForm\u{121ae}: '𒆮'
SignKu7\u{121af}: '𒆯'
SignKul\u{121b0}: '𒆰'
SignKulGunu\u{121b1}: '𒆱'
SignKun\u{121b2}: '𒆲'
SignKur\u{121b3}: '𒆳'
SignKurOpposingKur\u{121b4}: '𒆴'
SignKushu2\u{121b5}: '𒆵'
SignKwu318\u{121b6}: '𒆶'
SignLa\u{121b7}: '𒆷'
SignLagab\u{121b8}: '𒆸'
SignLagabTimesA\u{121b9}: '𒆹'
SignLagabTimesAPlusDaPlusHa\u{121ba}: '𒆺'
SignLagabTimesAPlusGar\u{121bb}: '𒆻'
SignLagabTimesAPlusLal\u{121bc}: '𒆼'
SignLagabTimesAl\u{121bd}: '𒆽'
SignLagabTimesAn\u{121be}: '𒆾'
SignLagabTimesAshZidaTenu\u{121bf}: '𒆿'
SignLagabTimesBad\u{121c0}: '𒇀'
SignLagabTimesBi\u{121c1}: '𒇁'
SignLagabTimesDar\u{121c2}: '𒇂'
SignLagabTimesEn\u{121c3}: '𒇃'
SignLagabTimesGa\u{121c4}: '𒇄'
SignLagabTimesGar\u{121c5}: '𒇅'
SignLagabTimesGud\u{121c6}: '𒇆'
SignLagabTimesGudPlusGud\u{121c7}: '𒇇'
SignLagabTimesHa\u{121c8}: '𒇈'
SignLagabTimesHal\u{121c9}: '𒇉'
SignLagabTimesHiTimesNun\u{121ca}: '𒇊'
SignLagabTimesIgiGunu\u{121cb}: '𒇋'
SignLagabTimesIm\u{121cc}: '𒇌'
SignLagabTimesImPlusHa\u{121cd}: '𒇍'
SignLagabTimesImPlusLu\u{121ce}: '𒇎'
SignLagabTimesKi\u{121cf}: '𒇏'
SignLagabTimesKin\u{121d0}: '𒇐'
SignLagabTimesKu3\u{121d1}: '𒇑'
SignLagabTimesKul\u{121d2}: '𒇒'
SignLagabTimesKulPlusHiPlusA\u{121d3}: '𒇓'
SignLagabTimesLagab\u{121d4}: '𒇔'
SignLagabTimesLish\u{121d5}: '𒇕'
SignLagabTimesLu\u{121d6}: '𒇖'
SignLagabTimesLul\u{121d7}: '𒇗'
SignLagabTimesMe\u{121d8}: '𒇘'
SignLagabTimesMePlusEn\u{121d9}: '𒇙'
SignLagabTimesMush\u{121da}: '𒇚'
SignLagabTimesNe\u{121db}: '𒇛'
SignLagabTimesShePlusSum\u{121dc}: '𒇜'
SignLagabTimesShitaPlusGishPlusErin2\u{121dd}: '𒇝'
SignLagabTimesShitaPlusGishTenu\u{121de}: '𒇞'
SignLagabTimesShu2\u{121df}: '𒇟'
SignLagabTimesShu2PlusShu2\u{121e0}: '𒇠'
SignLagabTimesSum\u{121e1}: '𒇡'
SignLagabTimesTag\u{121e2}: '𒇢'
SignLagabTimesTak4\u{121e3}: '𒇣'
SignLagabTimesTePlusAPlusSuPlusNa\u{121e4}: '𒇤'
SignLagabTimesU\u{121e5}: '𒇥'
SignLagabTimesUPlusA\u{121e6}: '𒇦'
SignLagabTimesUPlusUPlusU\u{121e7}: '𒇧'
SignLagabTimesU2PlusAsh\u{121e8}: '𒇨'
SignLagabTimesUd\u{121e9}: '𒇩'
SignLagabTimesUsh\u{121ea}: '𒇪'
SignLagabSquared\u{121eb}: '𒇫'
SignLagar\u{121ec}: '𒇬'
SignLagarTimesShe\u{121ed}: '𒇭'
SignLagarTimesShePlusSum\u{121ee}: '𒇮'
SignLagarGunu\u{121ef}: '𒇯'
SignLagarGunuOverLagarGunuShe\u{121f0}: '𒇰'
SignLahshu\u{121f1}: '𒇱'
SignLal\u{121f2}: '𒇲'
SignLalTimesLal\u{121f3}: '𒇳'
SignLam\u{121f4}: '𒇴'
SignLamTimesKur\u{121f5}: '𒇵'
SignLamTimesKurPlusRu\u{121f6}: '𒇶'
SignLi\u{121f7}: '𒇷'
SignLil\u{121f8}: '𒇸'
SignLimmu2\u{121f9}: '𒇹'
SignLish\u{121fa}: '𒇺'
SignLu\u{121fb}: '𒇻'
SignLuTimesBad\u{121fc}: '𒇼'
SignLu2\u{121fd}: '𒇽'
SignLu2TimesAl\u{121fe}: '𒇾'
SignLu2TimesBad\u{121ff}: '𒇿'
SignLu2TimesEsh2\u{12200}: '𒈀'
SignLu2TimesEsh2Tenu\u{12201}: '𒈁'
SignLu2TimesGan2Tenu\u{12202}: '𒈂'
SignLu2TimesHiTimesBad\u{12203}: '𒈃'
SignLu2TimesIm\u{12204}: '𒈄'
SignLu2TimesKad2\u{12205}: '𒈅'
SignLu2TimesKad3\u{12206}: '𒈆'
SignLu2TimesKad3PlusAsh\u{12207}: '𒈇'
SignLu2TimesKi\u{12208}: '𒈈'
SignLu2TimesLaPlusAsh\u{12209}: '𒈉'
SignLu2TimesLagab\u{1220a}: '𒈊'
SignLu2TimesMePlusEn\u{1220b}: '𒈋'
SignLu2TimesNe\u{1220c}: '𒈌'
SignLu2TimesNu\u{1220d}: '𒈍'
SignLu2TimesSiPlusAsh\u{1220e}: '𒈎'
SignLu2TimesSik2PlusBu\u{1220f}: '𒈏'
SignLu2TimesTug2\u{12210}: '𒈐'
SignLu2Tenu\u{12211}: '𒈑'
SignLu2CrossingLu2\u{12212}: '𒈒'
SignLu2OpposingLu2\u{12213}: '𒈓'
SignLu2Squared\u{12214}: '𒈔'
SignLu2Sheshig\u{12215}: '𒈕'
SignLu3\u{12216}: '𒈖'
SignLugal\u{12217}: '𒈗'
SignLugalOverLugal\u{12218}: '𒈘'
SignLugalOpposingLugal\u{12219}: '𒈙'
SignLugalSheshig\u{1221a}: '𒈚'
SignLuh\u{1221b}: '𒈛'
SignLul\u{1221c}: '𒈜'
SignLum\u{1221d}: '𒈝'
SignLumOverLum\u{1221e}: '𒈞'
SignLumOverLumGarOverGar\u{1221f}: '𒈟'
SignMa\u{12220}: '𒈠'
SignMaTimesTak4\u{12221}: '𒈡'
SignMaGunu\u{12222}: '𒈢'
SignMa2\u{12223}: '𒈣'
SignMah\u{12224}: '𒈤'
SignMar\u{12225}: '𒈥'
SignMash\u{12226}: '𒈦'
SignMash2\u{12227}: '𒈧'
SignMe\u{12228}: '𒈨'
SignMes\u{12229}: '𒈩'
SignMi\u{1222a}: '𒈪'
SignMin\u{1222b}: '𒈫'
SignMu\u{1222c}: '𒈬'
SignMuOverMu\u{1222d}: '𒈭'
SignMug\u{1222e}: '𒈮'
SignMugGunu\u{1222f}: '𒈯'
SignMunsub\u{12230}: '𒈰'
SignMurgu2\u{12231}: '𒈱'
SignMush\u{12232}: '𒈲'
SignMushTimesA\u{12233}: '𒈳'
SignMushTimesKur\u{12234}: '𒈴'
SignMushTimesZa\u{12235}: '𒈵'
SignMushOverMush\u{12236}: '𒈶'
SignMushOverMushTimesAPlusNa\u{12237}: '𒈷'
SignMushCrossingMush\u{12238}: '𒈸'
SignMush3\u{12239}: '𒈹'
SignMush3TimesA\u{1223a}: '𒈺'
SignMush3TimesAPlusDi\u{1223b}: '𒈻'
SignMush3TimesDi\u{1223c}: '𒈼'
SignMush3Gunu\u{1223d}: '𒈽'
SignNa\u{1223e}: '𒈾'
SignNa2\u{1223f}: '𒈿'
SignNaga\u{12240}: '𒉀'
SignNagaInverted\u{12241}: '𒉁'
SignNagaTimesShuTenu\u{12242}: '𒉂'
SignNagaOpposingNaga\u{12243}: '𒉃'
SignNagar\u{12244}: '𒉄'
SignNamNutillu\u{12245}: '𒉅'
SignNam\u{12246}: '𒉆'
SignNam2\u{12247}: '𒉇'
SignNe\u{12248}: '𒉈'
SignNeTimesA\u{12249}: '𒉉'
SignNeTimesUd\u{1224a}: '𒉊'
SignNeSheshig\u{1224b}: '𒉋'
SignNi\u{1224c}: '𒉌'
SignNiTimesE\u{1224d}: '𒉍'
SignNi2\u{1224e}: '𒉎'
SignNim\u{1224f}: '𒉏'
SignNimTimesGan2Tenu\u{12250}: '𒉐'
SignNimTimesGarPlusGan2Tenu\u{12251}: '𒉑'
SignNinda2\u{12252}: '𒉒'
SignNinda2TimesAn\u{12253}: '𒉓'
SignNinda2TimesAsh\u{12254}: '𒉔'
SignNinda2TimesAshPlusAsh\u{12255}: '𒉕'
SignNinda2TimesGud\u{12256}: '𒉖'
SignNinda2TimesMePlusGan2Tenu\u{12257}: '𒉗'
SignNinda2TimesNe\u{12258}: '𒉘'
SignNinda2TimesNun\u{12259}: '𒉙'
SignNinda2TimesShe\u{1225a}: '𒉚'
SignNinda2TimesShePlusAAn\u{1225b}: '𒉛'
SignNinda2TimesShePlusAsh\u{1225c}: '𒉜'
SignNinda2TimesShePlusAshPlusAsh\u{1225d}: '𒉝'
SignNinda2TimesU2PlusAsh\u{1225e}: '𒉞'
SignNinda2TimesUsh\u{1225f}: '𒉟'
SignNisag\u{12260}: '𒉠'
SignNu\u{12261}: '𒉡'
SignNu11\u{12262}: '𒉢'
SignNun\u{12263}: '𒉣'
SignNunLagarTimesGar\u{12264}: '𒉤'
SignNunLagarTimesMash\u{12265}: '𒉥'
SignNunLagarTimesSal\u{12266}: '𒉦'
SignNunLagarTimesSalOverNunLagarTimesSal\u{12267}: '𒉧'
SignNunLagarTimesUsh\u{12268}: '𒉨'
SignNunTenu\u{12269}: '𒉩'
SignNunOverNun\u{1226a}: '𒉪'
SignNunCrossingNun\u{1226b}: '𒉫'
SignNunCrossingNunLagarOverLagar\u{1226c}: '𒉬'
SignNunuz\u{1226d}: '𒉭'
SignNunuzAb2TimesAshgab\u{1226e}: '𒉮'
SignNunuzAb2TimesBi\u{1226f}: '𒉯'
SignNunuzAb2TimesDug\u{12270}: '𒉰'
SignNunuzAb2TimesGud\u{12271}: '𒉱'
SignNunuzAb2TimesIgiGunu\u{12272}: '𒉲'
SignNunuzAb2TimesKad3\u{12273}: '𒉳'
SignNunuzAb2TimesLa\u{12274}: '𒉴'
SignNunuzAb2TimesNe\u{12275}: '𒉵'
SignNunuzAb2TimesSila3\u{12276}: '𒉶'
SignNunuzAb2TimesU2\u{12277}: '𒉷'
SignNunuzKisim5TimesBi\u{12278}: '𒉸'
SignNunuzKisim5TimesBiU\u{12279}: '𒉹'
SignPa\u{1227a}: '𒉺'
SignPad\u{1227b}: '𒉻'
SignPan\u{1227c}: '𒉼'
SignPap\u{1227d}: '𒉽'
SignPesh2\u{1227e}: '𒉾'
SignPi\u{1227f}: '𒉿'
SignPiTimesA\u{12280}: '𒊀'
SignPiTimesAb\u{12281}: '𒊁'
SignPiTimesBi\u{12282}: '𒊂'
SignPiTimesBu\u{12283}: '𒊃'
SignPiTimesE\u{12284}: '𒊄'
SignPiTimesI\u{12285}: '𒊅'
SignPiTimesIb\u{12286}: '𒊆'
SignPiTimesU\u{12287}: '𒊇'
SignPiTimesU2\u{12288}: '𒊈'
SignPiCrossingPi\u{12289}: '𒊉'
SignPirig\u{1228a}: '𒊊'
SignPirigTimesKal\u{1228b}: '𒊋'
SignPirigTimesUd\u{1228c}: '𒊌'
SignPirigTimesZa\u{1228d}: '𒊍'
SignPirigOpposingPirig\u{1228e}: '𒊎'
SignRa\u{1228f}: '𒊏'
SignRab\u{12290}: '𒊐'
SignRi\u{12291}: '𒊑'
SignRu\u{12292}: '𒊒'
SignSa\u{12293}: '𒊓'
SignSagNutillu\u{12294}: '𒊔'
SignSag\u{12295}: '𒊕'
SignSagTimesA\u{12296}: '𒊖'
SignSagTimesDu\u{12297}: '𒊗'
SignSagTimesDub\u{12298}: '𒊘'
SignSagTimesHa\u{12299}: '𒊙'
SignSagTimesKak\u{1229a}: '𒊚'
SignSagTimesKur\u{1229b}: '𒊛'
SignSagTimesLum\u{1229c}: '𒊜'
SignSagTimesMi\u{1229d}: '𒊝'
SignSagTimesNun\u{1229e}: '𒊞'
SignSagTimesSal\u{1229f}: '𒊟'
SignSagTimesShid\u{122a0}: '𒊠'
SignSagTimesTab\u{122a1}: '𒊡'
SignSagTimesU2\u{122a2}: '𒊢'
SignSagTimesUb\u{122a3}: '𒊣'
SignSagTimesUm\u{122a4}: '𒊤'
SignSagTimesUr\u{122a5}: '𒊥'
SignSagTimesUsh\u{122a6}: '𒊦'
SignSagOverSag\u{122a7}: '𒊧'
SignSagGunu\u{122a8}: '𒊨'
SignSal\u{122a9}: '𒊩'
SignSalLagabTimesAsh2\u{122aa}: '𒊪'
SignSanga2\u{122ab}: '𒊫'
SignSar\u{122ac}: '𒊬'
SignSha\u{122ad}: '𒊭'
SignSha3\u{122ae}: '𒊮'
SignSha3TimesA\u{122af}: '𒊯'
SignSha3TimesBad\u{122b0}: '𒊰'
SignSha3TimesGish\u{122b1}: '𒊱'
SignSha3TimesNe\u{122b2}: '𒊲'
SignSha3TimesShu2\u{122b3}: '𒊳'
SignSha3TimesTur\u{122b4}: '𒊴'
SignSha3TimesU\u{122b5}: '𒊵'
SignSha3TimesUPlusA\u{122b6}: '𒊶'
SignSha6\u{122b7}: '𒊷'
SignShab6\u{122b8}: '𒊸'
SignShar2\u{122b9}: '𒊹'
SignShe\u{122ba}: '𒊺'
SignSheHu\u{122bb}: '𒊻'
SignSheOverSheGadOverGadGarOverGar\u{122bc}: '𒊼'
SignSheOverSheTabOverTabGarOverGar\u{122bd}: '𒊽'
SignSheg9\u{122be}: '𒊾'
SignShen\u{122bf}: '𒊿'
SignShesh\u{122c0}: '𒋀'
SignShesh2\u{122c1}: '𒋁'
SignSheshlam\u{122c2}: '𒋂'
SignShid\u{122c3}: '𒋃'
SignShidTimesA\u{122c4}: '𒋄'
SignShidTimesIm\u{122c5}: '𒋅'
SignShim\u{122c6}: '𒋆'
SignShimTimesA\u{122c7}: '𒋇'
SignShimTimesBal\u{122c8}: '𒋈'
SignShimTimesBulug\u{122c9}: '𒋉'
SignShimTimesDin\u{122ca}: '𒋊'
SignShimTimesGar\u{122cb}: '𒋋'
SignShimTimesIgi\u{122cc}: '𒋌'
SignShimTimesIgiGunu\u{122cd}: '𒋍'
SignShimTimesKushu2\u{122ce}: '𒋎'
SignShimTimesLul\u{122cf}: '𒋏'
SignShimTimesMug\u{122d0}: '𒋐'
SignShimTimesSal\u{122d1}: '𒋑'
SignShinig\u{122d2}: '𒋒'
SignShir\u{122d3}: '𒋓'
SignShirTenu\u{122d4}: '𒋔'
SignShirOverShirBurOverBur\u{122d5}: '𒋕'
SignShita\u{122d6}: '𒋖'
SignShu\u{122d7}: '𒋗'
SignShuOverInvertedShu\u{122d8}: '𒋘'
SignShu2\u{122d9}: '𒋙'
SignShubur\u{122da}: '𒋚'
SignSi\u{122db}: '𒋛'
SignSiGunu\u{122dc}: '𒋜'
SignSig\u{122dd}: '𒋝'
SignSig4\u{122de}: '𒋞'
SignSig4OverSig4Shu2\u{122df}: '𒋟'
SignSik2\u{122e0}: '𒋠'
SignSila3\u{122e1}: '𒋡'
SignSu\u{122e2}: '𒋢'
SignSuOverSu\u{122e3}: '𒋣'
SignSud\u{122e4}: '𒋤'
SignSud2\u{122e5}: '𒋥'
SignSuhur\u{122e6}: '𒋦'
SignSum\u{122e7}: '𒋧'
SignSumash\u{122e8}: '𒋨'
SignSur\u{122e9}: '𒋩'
SignSur9\u{122ea}: '𒋪'
SignTa\u{122eb}: '𒋫'
SignTaAsterisk\u{122ec}: '𒋬'
SignTaTimesHi\u{122ed}: '𒋭'
SignTaTimesMi\u{122ee}: '𒋮'
SignTaGunu\u{122ef}: '𒋯'
SignTab\u{122f0}: '𒋰'
SignTabOverTabNiOverNiDishOverDish\u{122f1}: '𒋱'
SignTabSquared\u{122f2}: '𒋲'
SignTag\u{122f3}: '𒋳'
SignTagTimesBi\u{122f4}: '𒋴'
SignTagTimesGud\u{122f5}: '𒋵'
SignTagTimesShe\u{122f6}: '𒋶'
SignTagTimesShu\u{122f7}: '𒋷'
SignTagTimesTug2\u{122f8}: '𒋸'
SignTagTimesUd\u{122f9}: '𒋹'
SignTak4\u{122fa}: '𒋺'
SignTar\u{122fb}: '𒋻'
SignTe\u{122fc}: '𒋼'
SignTeGunu\u{122fd}: '𒋽'
SignTi\u{122fe}: '𒋾'
SignTiTenu\u{122ff}: '𒋿'
SignTil\u{12300}: '𒌀'
SignTir\u{12301}: '𒌁'
SignTirTimesTak4\u{12302}: '𒌂'
SignTirOverTir\u{12303}: '𒌃'
SignTirOverTirGadOverGadGarOverGar\u{12304}: '𒌄'
SignTu\u{12305}: '𒌅'
SignTug2\u{12306}: '𒌆'
SignTuk\u{12307}: '𒌇'
SignTum\u{12308}: '𒌈'
SignTur\u{12309}: '𒌉'
SignTurOverTurZaOverZa\u{1230a}: '𒌊'
SignU\u{1230b}: '𒌋'
SignUGud\u{1230c}: '𒌌'
SignUUU\u{1230d}: '𒌍'
SignUOverUPaOverPaGarOverGar\u{1230e}: '𒌎'
SignUOverUSurOverSur\u{1230f}: '𒌏'
SignUOverUUReversedOverUReversed\u{12310}: '𒌐'
SignU2\u{12311}: '𒌑'
SignUb\u{12312}: '𒌒'
SignUd\u{12313}: '𒌓'
SignUdKushu2\u{12314}: '𒌔'
SignUdTimesBad\u{12315}: '𒌕'
SignUdTimesMi\u{12316}: '𒌖'
SignUdTimesUPlusUPlusU\u{12317}: '𒌗'
SignUdTimesUPlusUPlusUGunu\u{12318}: '𒌘'
SignUdGunu\u{12319}: '𒌙'
SignUdSheshig\u{1231a}: '𒌚'
SignUdSheshigTimesBad\u{1231b}: '𒌛'
SignUdug\u{1231c}: '𒌜'
SignUm\u{1231d}: '𒌝'
SignUmTimesLagab\u{1231e}: '𒌞'
SignUmTimesMePlusDa\u{1231f}: '𒌟'
SignUmTimesSha3\u{12320}: '𒌠'
SignUmTimesU\u{12321}: '𒌡'
SignUmbin\u{12322}: '𒌢'
SignUmum\u{12323}: '𒌣'
SignUmumTimesKaskal\u{12324}: '𒌤'
SignUmumTimesPa\u{12325}: '𒌥'
SignUn\u{12326}: '𒌦'
SignUnGunu\u{12327}: '𒌧'
SignUr\u{12328}: '𒌨'
SignUrCrossingUr\u{12329}: '𒌩'
SignUrSheshig\u{1232a}: '𒌪'
SignUr2\u{1232b}: '𒌫'
SignUr2TimesAPlusHa\u{1232c}: '𒌬'
SignUr2TimesAPlusNa\u{1232d}: '𒌭'
SignUr2TimesAl\u{1232e}: '𒌮'
SignUr2TimesHa\u{1232f}: '𒌯'
SignUr2TimesNun\u{12330}: '𒌰'
SignUr2TimesU2\u{12331}: '𒌱'
SignUr2TimesU2PlusAsh\u{12332}: '𒌲'
SignUr2TimesU2PlusBi\u{12333}: '𒌳'
SignUr4\u{12334}: '𒌴'
SignUri\u{12335}: '𒌵'
SignUri3\u{12336}: '𒌶'
SignUru\u{12337}: '𒌷'
SignUruTimesA\u{12338}: '𒌸'
SignUruTimesAshgab\u{12339}: '𒌹'
SignUruTimesBar\u{1233a}: '𒌺'
SignUruTimesDun\u{1233b}: '𒌻'
SignUruTimesGa\u{1233c}: '𒌼'
SignUruTimesGal\u{1233d}: '𒌽'
SignUruTimesGan2Tenu\u{1233e}: '𒌾'
SignUruTimesGar\u{1233f}: '𒌿'
SignUruTimesGu\u{12340}: '𒍀'
SignUruTimesHa\u{12341}: '𒍁'
SignUruTimesIgi\u{12342}: '𒍂'
SignUruTimesIm\u{12343}: '𒍃'
SignUruTimesIsh\u{12344}: '𒍄'
SignUruTimesKi\u{12345}: '𒍅'
SignUruTimesLum\u{12346}: '𒍆'
SignUruTimesMin\u{12347}: '𒍇'
SignUruTimesPa\u{12348}: '𒍈'
SignUruTimesShe\u{12349}: '𒍉'
SignUruTimesSig4\u{1234a}: '𒍊'
SignUruTimesTu\u{1234b}: '𒍋'
SignUruTimesUPlusGud\u{1234c}: '𒍌'
SignUruTimesUd\u{1234d}: '𒍍'
SignUruTimesUruda\u{1234e}: '𒍎'
SignUruda\u{1234f}: '𒍏'
SignUrudaTimesU\u{12350}: '𒍐'
SignUsh\u{12351}: '𒍑'
SignUshTimesA\u{12352}: '𒍒'
SignUshTimesKu\u{12353}: '𒍓'
SignUshTimesKur\u{12354}: '𒍔'
SignUshTimesTak4\u{12355}: '𒍕'
SignUshx\u{12356}: '𒍖'
SignUsh2\u{12357}: '𒍗'
SignUshumx\u{12358}: '𒍘'
SignUtuki\u{12359}: '𒍙'
SignUz3\u{1235a}: '𒍚'
SignUz3TimesKaskal\u{1235b}: '𒍛'
SignUzu\u{1235c}: '𒍜'
SignZa\u{1235d}: '𒍝'
SignZaTenu\u{1235e}: '𒍞'
SignZaSquaredTimesKur\u{1235f}: '𒍟'
SignZag\u{12360}: '𒍠'
SignZamx\u{12361}: '𒍡'
SignZe2\u{12362}: '𒍢'
SignZi\u{12363}: '𒍣'
SignZiOverZi\u{12364}: '𒍤'
SignZi3\u{12365}: '𒍥'
SignZib\u{12366}: '𒍦'
SignZibKabaTenu\u{12367}: '𒍧'
SignZig\u{12368}: '𒍨'
SignZiz2\u{12369}: '𒍩'
SignZu\u{1236a}: '𒍪'
SignZu5\u{1236b}: '𒍫'
SignZu5TimesA\u{1236c}: '𒍬'
SignZubur\u{1236d}: '𒍭'
SignZum\u{1236e}: '𒍮'
SignKapElamite\u{1236f}: '𒍯'
SignAbTimesNun\u{12370}: '𒍰'
SignAb2TimesA\u{12371}: '𒍱'
SignAmarTimesKug\u{12372}: '𒍲'
SignDagKisim5TimesU2PlusMash\u{12373}: '𒍳'
SignDag3\u{12374}: '𒍴'
SignDishPlusShu\u{12375}: '𒍵'
SignDubTimesShe\u{12376}: '𒍶'
SignEzenTimesGud\u{12377}: '𒍷'
SignEzenTimesShe\u{12378}: '𒍸'
SignGa2TimesAnPlusKakPlusA\u{12379}: '𒍹'
SignGa2TimesAsh2\u{1237a}: '𒍺'
SignGe22\u{1237b}: '𒍻'
SignGig\u{1237c}: '𒍼'
SignHush\u{1237d}: '𒍽'
SignKaTimesAnshe\u{1237e}: '𒍾'
SignKaTimesAsh3\u{1237f}: '𒍿'
SignKaTimesGish\u{12380}: '𒎀'
SignKaTimesGud\u{12381}: '𒎁'
SignKaTimesHiTimesAsh2\u{12382}: '𒎂'
SignKaTimesLum\u{12383}: '𒎃'
SignKaTimesPa\u{12384}: '𒎄'
SignKaTimesShul\u{12385}: '𒎅'
SignKaTimesTu\u{12386}: '𒎆'
SignKaTimesUr2\u{12387}: '𒎇'
SignLagabTimesGi\u{12388}: '𒎈'
SignLu2SheshigTimesBad\u{12389}: '𒎉'
SignLu2TimesEsh2PlusLal\u{1238a}: '𒎊'
SignLu2TimesShu\u{1238b}: '𒎋'
SignMesh\u{1238c}: '𒎌'
SignMush3TimesZa\u{1238d}: '𒎍'
SignNa4\u{1238e}: '𒎎'
SignNin\u{1238f}: '𒎏'
SignNin9\u{12390}: '𒎐'
SignNinda2TimesBal\u{12391}: '𒎑'
SignNinda2TimesGi\u{12392}: '𒎒'
SignNu11RotatedNinetyDegrees\u{12393}: '𒎓'
SignPesh2Asterisk\u{12394}: '𒎔'
SignPir2\u{12395}: '𒎕'
SignSagTimesIgiGunu\u{12396}: '𒎖'
SignTi2\u{12397}: '𒎗'
SignUmTimesMe\u{12398}: '𒎘'
SignUU\u{12399}: '𒎙'
Methods
impl Cuneiform[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case